-- http://lua-users.org/wiki/PatternsTutorial

function love.load()
    --love.filesystem.setIdentity("display-file") -- needed for writing text

    audioSource = love.audio.newSource("audioFile.mp3")
    love.audio.play(audioSource) 
    playing = true
    
    --get the file.
    file = love.filesystem.newFile("audioTextFile.txt")
    file:open('r')
    textLump = file:read() 
    -- some text to try...
    text = "Sample text [start 2.0]This first[end 4.5] this should not be visible [start 5.0]then this [end 7.0]more ignored text [start 10.0]finally this.[end 11.5]"

    --break up the text in the file and inset into categorised table arrays.
    startsArray = {}
    endsArray = {}
    wordsArray = {}
    for starts, words, ends in textLump:gmatch("%[start%s([%d%.]+)%](.-)%[end%s([%d%.]+)%]") do
        table.insert(startsArray, tonumber(starts) )
        table.insert(endsArray, tonumber(ends) )
        table.insert(wordsArray, words)
    end    -- all strings are now in t{}. Now we can pull them out and print them. 
    
    tableIndex = 1 -- this is the start of the table array and a base for incrementation.
    tableLength = #startsArray -- how many table items we have. 
    textCall = "Easy Video Language"
    font = love.graphics.newFont(66)
    love.graphics.setFont(font)
    windowHeight = love.graphics.getHeight()
    love.graphics.setBackgroundColor(123, 17, 19) -- maroon background
end

--

function love.keypressed(key)
    if key == "f5" then
        -- print debug info to console.
    end
        
    if key == "f1" then
        if playing then
            love.audio.pause(audioSource)
        else
            love.audio.resume(audioSource)    
        end    
        playing = not playing -- swap state
        print("PLAY/PAUSE")
    end
    
    if key == "escape" then 
        love.event.push("quit") 
    end
end

--

function love.update(dt)
    position = audioSource:tell( "seconds" )
    if tableIndex < tableLength + 1 then -- 
        if position > startsArray[tableIndex] then
            textCall = tostring(wordsArray[tableIndex])
            print(startsArray[tableIndex] .. " | " .. wordsArray[tableIndex] .. " | " .. string.format("%f", position) )
            tableIndex = tableIndex + 1
        end
    end
end

--

function love.draw()
    love.graphics.setColor(193, 160, 4) -- yellow text
    love.graphics.printf(textCall, 10, windowHeight / 3, 800, 'center') -- Default title -- set in love.load()
    love.graphics.setColor(193, 160, 255)
    love.graphics.printf(position, 10, 0, 800) -- check text is arriving on time.
end

--
